@@ -458,6 +458,8 @@ if __name__ == "__main__":
     duration_seconds = args.duration_seconds
     profile = args.profile
     role_arn = args.role_arn
+    if args.profile is None:
+        profile = 'saml'
 
     if args.url is None:
         try:
